<?php

namespace Bixo\Organization\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Organization\Actions\OrganizationAction;
use Bixo\Organization\Http\Requests\OrganizationActionRequest;
use Bixo\Organization\Http\Resources\OrganizationResource;
use Bixo\Organization\Models\Organization;

/**
 * Admin web controller class.
 */
class OrganizationActionController extends BaseController
{

    /**
     * Action controller function for organization.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(OrganizationActionRequest $request, Organization $organization, $action)
    {
        try {
            $request = $request->all();
            $organization = OrganizationAction::run($action, $organization, $request);

            $data = new OrganizationResource($organization);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('organization::organization.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('organization/organization/' . $organization->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('organization/organization/' . $organization->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
