<?php

namespace Bixo\Organization\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Bixo\Organization\Http\Requests\OrganizationActionsRequest;
use Bixo\Organization\Actions\OrganizationActions;

/**
 * Admin web controller class.
 */
class OrganizationActionsController extends BaseController
{

    /**
     * Action controller function for organization.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(OrganizationActionsRequest $request, $action)
    {
        try {
            $organization = OrganizationActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('organization::organization.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('organization/organization/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('organization/organization/' . $action))
                ->redirect();
        }
    }
}
