<?php

namespace Bixo\Organization\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Organization\Models\Organization;

class OrganizationPolicy
{

    use OrganizationAction;
    use OrganizationReport;
    use OrganizationWorkflow;

    /**
     * Determine if the given user can view the organization.
     *
     * @param Authenticatable $user
     * @param Organization $organization
     *
     * @return bool
     */
    public function view(Authenticatable $user, Organization $organization)
    {
        if ($authUser->canDo('organization.organization.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $organization->is_owner;
    }

    /**
     * Determine if the given user can create a organization.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('organization.organization.create');
    }

    /**
     * Determine if the given user can update the given organization.
     *
     * @param Authenticatable $user
     * @param Organization $organization
     *
     * @return bool
     */
    public function update(Authenticatable $user, Organization $organization)
    {
        if ($user->canDo('organization.organization.edit') && $user->isAdmin()) {
            return true;
        }

        return $organization->is_owner;
    }

    /**
     * Determine if the given user can delete the given organization.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Organization $organization)
    {
        return $organization->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
