<?php

namespace Bixo\Organization\Providers;

use Illuminate\Support\ServiceProvider;
use Bixo\Organization\Organizations;

class OrganizationServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'organization');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'organization');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        $this->registerCommands();

        $this->app->register(\Bixo\Organization\Providers\AuthServiceProvider::class);
        $this->app->register(\Bixo\Organization\Providers\RouteServiceProvider::class);
        $this->app->register(\Bixo\Organization\Providers\ActionServiceProvider::class);
        $this->app->register(\Bixo\Organization\Providers\EventServiceProvider::class);
        $this->app->register(\Bixo\Organization\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('bixo.organization', function($app)
        {
            return $this->app->make(Organization::class);
        });
    }

    /**
     * Merges user's and organization's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'bixo.organization'
        );
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/organization.php', 'bixo.organization.organization'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/user.php', 'bixo.organization.user'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Bixo\Organization\Commands\Organization::class,
            ]);
        }
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['bixo.organization'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('bixo/organization')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/organization')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/organization')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
